@@ -107,20 +107,22 @@ def stage(
 @require(lambda bundle: isinstance(bundle, str) and len(bundle) > 0, "Bundle name must be non-empty string")
 @require(lambda sdd: sdd is None or isinstance(sdd, Path), "SDD must be None or Path")
 @require(
-    lambda format: isinstance(format, str) and format.lower() in ("yaml", "json", "markdown"),
-    "Format must be yaml, json, or markdown",
+    lambda output_format: isinstance(output_format, str) and output_format.lower() in ("yaml", "json", "markdown"),
+    "Output format must be yaml, json, or markdown",
 )
 @require(lambda out: out is None or isinstance(out, Path), "Out must be None or Path")
 def enforce_sdd(
+    # Target/Input
     bundle: str = typer.Argument(..., help="Project bundle name (e.g., legacy-api, auth-module)"),
     sdd: Path | None = typer.Option(
         None,
         "--sdd",
         help="Path to SDD manifest (default: .specfact/sdd/<bundle-name>.<format>)",
     ),
-    format: str = typer.Option(
+    # Output/Results
+    output_format: str = typer.Option(
         "yaml",
-        "--format",
+        "--output-format",
         help="Output format (yaml, json, markdown)",
     ),
     out: Path | None = typer.Option(
@@ -128,9 +130,10 @@ def enforce_sdd(
         "--out",
         help="Output file path (default: .specfact/reports/sdd/validation-<timestamp>.<format>)",
     ),
-    non_interactive: bool = typer.Option(
+    # Behavior/Options
+    no_interactive: bool = typer.Option(
         False,
-        "--non-interactive",
+        "--no-interactive",
         help="Non-interactive mode (for CI/CD automation)",
     ),
 ) -> None:
@@ -145,7 +148,7 @@ def enforce_sdd(
 
     Example:
         specfact enforce sdd legacy-api
-        specfact enforce sdd auth-module --format json --out validation-report.json
+        specfact enforce sdd auth-module --output-format json --out validation-report.json
     """
     from specfact_cli.models.sdd import SDDManifest
     from specfact_cli.utils.bundle_loader import load_project_bundle
@@ -157,8 +160,8 @@ def enforce_sdd(
     )
 
     telemetry_metadata = {
-        "format": format.lower(),
-        "non_interactive": non_interactive,
+        "output_format": output_format.lower(),
+        "no_interactive": no_interactive,
     }
 
     with telemetry.track_command("enforce.sdd", telemetry_metadata) as record:
@@ -198,9 +201,24 @@ def enforce_sdd(
             sdd_data = load_structured_file(sdd)
             sdd_manifest = SDDManifest.model_validate(sdd_data)
 
-            # Load project bundle
-            console.print(f"[dim]Loading project bundle: {bundle_dir}[/dim]")
-            project_bundle = load_project_bundle(bundle_dir, validate_hashes=False)
+            # Load project bundle with progress indicator
+            from rich.progress import Progress, SpinnerColumn, TextColumn
+
+            with Progress(
+                SpinnerColumn(),
+                TextColumn("[progress.description]{task.description}"),
+                console=console,
+            ) as progress:
+                task = progress.add_task("Loading project bundle...", total=None)
+
+                def progress_callback(current: int, total: int, artifact: str) -> None:
+                    progress.update(task, description=f"Loading artifact {current}/{total}: {artifact}")
+
+                project_bundle = load_project_bundle(
+                    bundle_dir, validate_hashes=False, progress_callback=progress_callback
+                )
+                progress.update(task, description="✓ Bundle loaded, computing hash...")
+
             summary = project_bundle.compute_summary(include_hash=True)
             project_hash = summary.content_hash
 
@@ -286,19 +304,19 @@ def enforce_sdd(
                 # TODO: Implement hash-based frozen section validation in Phase 6
 
             # Generate output report
-            output_format = format.lower()
+            output_format_str = output_format.lower()
             if out is None:
                 SpecFactStructure.ensure_structure()
                 reports_dir = Path(".") / SpecFactStructure.ROOT / "reports" / "sdd"
                 reports_dir.mkdir(parents=True, exist_ok=True)
                 timestamp = datetime.now().strftime("%Y%m%d-%H%M%S")
-                extension = "md" if output_format == "markdown" else output_format
+                extension = "md" if output_format_str == "markdown" else output_format_str
                 out = reports_dir / f"validation-{timestamp}.{extension}"
 
             # Save report
-            if output_format == "markdown":
+            if output_format_str == "markdown":
                 _save_markdown_report(out, report, sdd_manifest, bundle, project_hash)
-            elif output_format == "json":
+            elif output_format_str == "json":
                 dump_structured_file(report.model_dump(mode="json"), out, StructuredFormat.JSON)
             else:  # yaml
                 dump_structured_file(report.model_dump(mode="json"), out, StructuredFormat.YAML)
@@ -312,9 +330,51 @@ def enforce_sdd(
             console.print(f"  Low: {report.low_count}")
             console.print(f"\nReport saved to: {out}")
 
-            # Exit with appropriate code
+            # Exit with appropriate code and clear error messages
             if not report.passed:
                 console.print("\n[bold red]✗[/bold red] SDD validation failed")
+                console.print("\n[bold yellow]Issues Found:[/bold yellow]")
+
+                # Group deviations by type for clearer messaging
+                hash_mismatches = [d for d in report.deviations if d.type == DeviationType.HASH_MISMATCH]
+                coverage_issues = [d for d in report.deviations if d.type == DeviationType.COVERAGE_THRESHOLD]
+
+                if hash_mismatches:
+                    console.print("\n[bold red]1. Hash Mismatch (HIGH)[/bold red]")
+                    console.print("   The project bundle has been modified since the SDD manifest was created.")
+                    console.print(f"   [dim]SDD hash: {sdd_manifest.plan_bundle_hash[:16]}...[/dim]")
+                    console.print(f"   [dim]Bundle hash: {project_hash[:16]}...[/dim]")
+                    console.print("\n   [bold]Why this happens:[/bold]")
+                    console.print("   The hash changes when you modify:")
+                    console.print("   - Features (add/remove/update)")
+                    console.print("   - Stories (add/remove/update)")
+                    console.print("   - Product, idea, business, or clarifications")
+                    console.print(
+                        f"\n   [bold]Fix:[/bold] Run [cyan]specfact plan harden {bundle}[/cyan] to update the SDD manifest"
+                    )
+                    console.print(
+                        "   [dim]This updates the SDD with the current bundle hash and regenerates HOW sections[/dim]"
+                    )
+
+                if coverage_issues:
+                    console.print("\n[bold yellow]2. Coverage Thresholds Not Met (MEDIUM)[/bold yellow]")
+                    console.print("   Contract density metrics are below required thresholds:")
+                    console.print(
+                        f"   - Contracts/story: {metrics.contracts_per_story:.2f} (required: {thresholds.contracts_per_story})"
+                    )
+                    console.print(
+                        f"   - Invariants/feature: {metrics.invariants_per_feature:.2f} (required: {thresholds.invariants_per_feature})"
+                    )
+                    console.print("\n   [bold]Fix:[/bold] Add more contracts to stories and invariants to features")
+                    console.print("   [dim]Tip: Use 'specfact plan review' to identify areas needing contracts[/dim]")
+
+                console.print("\n[bold cyan]Next Steps:[/bold cyan]")
+                if hash_mismatches:
+                    console.print(f"   1. Update SDD: [cyan]specfact plan harden {bundle}[/cyan]")
+                if coverage_issues:
+                    console.print("   2. Add contracts: Review features and add @icontract decorators")
+                    console.print("   3. Re-validate: Run this command again after fixes")
+
                 record({"passed": False, "deviations": report.total_deviations})
                 raise typer.Exit(1)
 
