@@ -77,7 +77,7 @@ def _perform_sync_operation(
     from specfact_cli.validators.schema import validate_plan_bundle
 
     probe = BridgeProbe(repo)
-    capabilities = probe.detect()
+    _ = probe.detect()  # Probe for detection, result not used in this path
 
     # For Spec-Kit adapter, use legacy scanner for now
     if adapter_type == AdapterType.SPECKIT:
@@ -213,7 +213,7 @@ def _perform_sync_operation(
             merged_bundle: PlanBundle | None = None
             features_updated = 0
             features_added = 0
-            
+
             if len(features) == 0:
                 task = progress.add_task(f"[cyan]📝[/cyan] Converting {adapter_type.value} → SpecFact...", total=None)
                 progress.update(
@@ -236,7 +236,8 @@ def _perform_sync_operation(
                         if is_valid and loaded_plan_bundle:
                             # Show progress during validation (Pydantic validation can be slow for large bundles)
                             progress.update(
-                                task, description=f"[cyan]Validating {len(loaded_plan_bundle.features)} features...[/cyan]"
+                                task,
+                                description=f"[cyan]Validating {len(loaded_plan_bundle.features)} features...[/cyan]",
                             )
                             merged_bundle = loaded_plan_bundle
                             progress.update(
@@ -245,10 +246,14 @@ def _perform_sync_operation(
                             )
                         else:
                             # Fallback: create minimal bundle via converter (but skip expensive parsing)
-                            progress.update(task, description=f"[cyan]Creating plan bundle from {adapter_type.value}...[/cyan]")
+                            progress.update(
+                                task, description=f"[cyan]Creating plan bundle from {adapter_type.value}...[/cyan]"
+                            )
                             merged_bundle = _sync_speckit_to_specfact(repo, converter, scanner, progress, task)[0]
                     else:
-                        progress.update(task, description=f"[cyan]Creating plan bundle from {adapter_type.value}...[/cyan]")
+                        progress.update(
+                            task, description=f"[cyan]Creating plan bundle from {adapter_type.value}...[/cyan]"
+                        )
                         merged_bundle = _sync_speckit_to_specfact(repo, converter, scanner, progress, task)[0]
                 else:
                     # No plan path found, create minimal bundle
@@ -298,7 +303,7 @@ def _perform_sync_operation(
                     from specfact_cli.commands.plan import _convert_project_bundle_to_plan_bundle
                     from specfact_cli.utils.bundle_loader import load_project_bundle
 
-                    bundle_dir = SpecFactStructure.project_dir(repo) / bundle
+                    bundle_dir = SpecFactStructure.project_dir(base_path=repo, bundle_name=bundle)
                     if bundle_dir.exists():
                         project_bundle = load_project_bundle(bundle_dir)
                         plan_bundle_to_convert = _convert_project_bundle_to_plan_bundle(project_bundle)
@@ -365,7 +370,9 @@ def _perform_sync_operation(
 
             if conflicts:
                 console.print(f"[yellow]⚠[/yellow] Found {len(conflicts)} conflicts")
-                console.print(f"[dim]Conflicts resolved using priority rules (SpecFact > {adapter_type.value} for artifacts)[/dim]")
+                console.print(
+                    f"[dim]Conflicts resolved using priority rules (SpecFact > {adapter_type.value} for artifacts)[/dim]"
+                )
             else:
                 console.print("[bold green]✓[/bold green] No conflicts detected")
         else:
@@ -405,7 +412,9 @@ def _perform_sync_operation(
         console.print()
         if bidirectional:
             console.print("[bold cyan]Sync Summary (Bidirectional):[/bold cyan]")
-            console.print(f"  - {adapter_type.value} → SpecFact: Updated {features_updated}, Added {features_added} features")
+            console.print(
+                f"  - {adapter_type.value} → SpecFact: Updated {features_updated}, Added {features_added} features"
+            )
             # Always show conversion result (we convert if plan bundle exists, not just when changes detected)
             if features_converted_speckit > 0:
                 console.print(
@@ -674,23 +683,20 @@ def sync_bridge(
         specfact sync bridge --repo . --bidirectional  # Auto-detect adapter
     """
     # Auto-detect adapter if not specified
-    if adapter == "speckit" or adapter == "auto":
-        from specfact_cli.sync.bridge_probe import BridgeProbe
+    from specfact_cli.sync.bridge_probe import BridgeProbe
 
+    if adapter == "speckit" or adapter == "auto":
         probe = BridgeProbe(repo)
-        capabilities = probe.detect()
-        if capabilities.tool == "speckit":
-            adapter = "speckit"
-        else:
-            adapter = "generic-markdown"
+        detected_capabilities = probe.detect()
+        adapter = "speckit" if detected_capabilities.tool == "speckit" else "generic-markdown"
 
     # Validate adapter
     try:
         adapter_type = AdapterType(adapter.lower())
-    except ValueError:
+    except ValueError as err:
         console.print(f"[bold red]✗[/bold red] Unsupported adapter: {adapter}")
         console.print(f"[dim]Supported adapters: {', '.join([a.value for a in AdapterType])}[/dim]")
-        raise typer.Exit(1)
+        raise typer.Exit(1) from err
 
     telemetry_metadata = {
         "adapter": adapter,
@@ -721,7 +727,7 @@ def sync_bridge(
             if bundle:
                 from specfact_cli.utils.bundle_loader import load_project_bundle
 
-                bundle_dir = SpecFactStructure.project_dir(repo) / bundle
+                bundle_dir = SpecFactStructure.project_dir(base_path=repo, bundle_name=bundle)
                 if bundle_dir.exists():
                     project_bundle = load_project_bundle(bundle_dir)
                     # Convert to PlanBundle for validation (legacy compatibility)
@@ -765,8 +771,7 @@ def sync_bridge(
                             1
                             for acc in story.acceptance
                             if any(
-                                keyword in acc.lower()
-                                for keyword in ["must", "should", "verify", "validate", "ensure"]
+                                keyword in acc.lower() for keyword in ["must", "should", "verify", "validate", "ensure"]
                             )
                         )
                         if testable_count < len(story.acceptance) and len(story.acceptance) > 0:
